/**
 * 命名常量,常用事件可以用这个，在WEB及客户端设备切换时，修改下列变量，达到事件有效性
 */
var NS = {
	ON_CLICK : "click",
	ON_ITEMTAP : "itemtap",
	ON_BEFORE_LOAD : "beforeLoad",
	ON_AFTER_LOAD : "afterLoad",
	ON_TOUCH_START : "touchstart",
	ON_TOUCH_MOVE : "touchmove",
	ON_TOUCH_START : "touchstart",
	ON_TOUCH_END : "touchend"
};
var Fw = {
	idSeed: 10000,
    /**
     * 返回ID
     * @param {Object} v
     */
    id: function(){
        return 'fw-gen-' + (++Fw.idSeed);
    },
    /**
     * 日志输出
     * @param info
     * @param tag
     */
    log: function(info,tag){
    	
    },
    /**
     * 空白函数
     */
    emptyFn:function(){},
    /**
     * 定义命名空间 
     */
    namespace: function(){
        var space = null, path;
        Fw.each(arguments, function(v) {
            path = v.split('.');
            space = window[path[0]] = window[path[0]] || {};
            Fw.each(path.slice(1), function(v2){
                space = space[v2] = space[v2] || {};
            });
        });
        return space;
    },
	/**
	 * 属性复制（同jQuery的$.extend）
	 * @param {} object
	 * @param {} config
	 * @param {} defaults
	 */
	apply: function(object, config, defaults){
	    if(defaults){
	        Fw.apply(object, defaults);
	    }
	    if(object && config && Fw.isObject(config)){
	        for(var property in config){
	            object[property] = config[property];
	        }
	    }
	    return object;
	},
    /**
     * 属性复制（仅复制object中不存在的属性）
     * @param {} object
     * @param {} config
     */
    applyIf: function(object, config) {
        if (object) {
            for (var p in config) {
                if (!Fw.isDefined(object[p])) {
                    object[p] = config[p];
                }
            }
        }
        return object;
    },
	/**
	 * 继承
	 */
    extend: function(){
        var objectConstructor = Object.prototype.constructor,
            inlineOverrides = function(o) {
            for (var m in o) {
                if (!o.hasOwnProperty(m)) {
                    continue;
                }
                this[m] = o[m];
            }
        };
        return function(subclass, superclass, overrides) {
            if (Fw.isObject(superclass)) {
                overrides = superclass;
                superclass = subclass;
                subclass = overrides.constructor !== objectConstructor ? overrides.constructor : function() {
                    superclass.apply(this, arguments);
                };
            }
            if (!superclass) {
                return null;
            }
            //
            var F = function() {};
            var subclassProto, superclassProto = superclass.prototype;
            F.prototype = superclassProto;
            subclassProto = subclass.prototype = new F();
            subclassProto.constructor = subclass;
            subclass.superclass = superclassProto;
            if (superclassProto.constructor === objectConstructor) {
                superclassProto.constructor = superclass;
            }
            subclass.override = function(overrides) {
                Fw.override(subclass, overrides);
            };
            subclassProto.override = inlineOverrides;
            subclassProto.proto = subclassProto;
            subclass.override(overrides);
            subclass.extend = function(o) {
                return Fw.extend(subclass, o);
            };
            return subclass;
        };
    }(),
    /**
     * 覆盖
     * @param {} cls
     * @param {} overrides
     */
    override: function(cls, overrides) {
        Fw.apply(cls.prototype, overrides);
    },
    /**
     * 转换为字符
     * @param {Object} v
     */
    toString: function(v){
        return Object.prototype.toString.apply(v);
    },
    /**
     * 是否已定义
     * @param {} v
     */
    isDefined: function(v){
        return typeof v !== 'undefined';
    },
    /**
     * 是否为空
     * @param {} v
     * @param {} allowBlank
     */
    isEmpty: function(v, allowBlank){
        return v === null || v === undefined  || String(v).toUpperCase() === 'NULL' || ((Fw.isArray(v) && !v.length)) || (!allowBlank ? v === '': false);
    },
    /**
     * 是否是数组
     * @param {} v
     */
    isArray: function(v){
        return Fw.toString(v) === '[object Array]';
    },
    /**
     * 是否是日期
     * @param {} v
     */
    isDate: function(v){
        return Fw.toString(v) === '[object Date]';
    },
    /**
     * 是否是对象
     * @param {} v
     */
    isObject: function(v){
        return !!v && Fw.toString(v) === '[object Object]';
    },
    /**
     * 是否是函数
     * @param {} v
     */
    isFunction: function(v){
        return Fw.toString(v) === '[object Function]';
    },
    /**
     * 是否是数值型
     * @param {} v
     */
    isNumber: function(v){
        return typeof v === 'number' && isFinite(v);
    },
    /**
     * 是否是字符型
     * @param {} v
     */
    isString: function(v){
        return typeof v === 'string';
    },
    /**
     * 是否是布尔型
     * @param {} v
     */
    isBoolean: function(v){
        return typeof v === 'boolean';
    },
    /**
     * 是否是原始类型 
     * @param {} v
     */
    isPrimitive : function(v){
        return Fw.isString(v) || Fw.isNumber(v) || Fw.isBoolean(v);
    },
    /**
     * 是否可迭代 
     * @param {} v
     */
    isIterable : function(v){
    	return (v && typeof v !== 'string') ? Fw.isDefined(v.length) : false;
    },
    /**
     * 是否是URL
     * @param {} v
     * @return {}
     */
    isUrl: function(v){
    	return /(((^https?)|(^ftp)):\/\/((([\-\w]+\.)+\w{2,3}(\/[%\-\w]+(\.\w{2,})?)*(([\w\-\.\?\\\/+@&#;`~=%!]*)(\.\w{2,})?)*)|(localhost|LOCALHOST))\/?)/i.test(v);
    },
    /**
     * 页面跳转
     * @param {} url
     * @param {} params
     */
    redirect: function(url, params){
    	var ps = Fw.encode(params);
		var search = document.location.search;
		if(!Fw.isEmpty(search)){
			search = search.replace(/(&?)t=[^&]+/g, ''); 
			search = search.replace(/(&?)parameters=[^&]+/g, '');
			url += search === '?' ? '' : search;
		}
		url += (url.indexOf('?') > 0 ? '&' : '?') + 't=' + new Date().getTime();
		if(!Fw.isEmpty(ps)){
			url += '&parameters=' + encodeURIComponent(ps);
		}
    	document.location.href = url;
    },
    /**
     * 返回parameters参数
     * 特指页面跳转间传递的参数
     */
    getParameters: function(){
    	if(Fw._parameters){
    		return Fw._parameters;
    	}
    	var ps = Fw.getParameter('parameters');
    	if(!Fw.isEmpty(ps)){
    		return Fw._parameters = Fw.decode(decodeURIComponent(ps));
    	}
    	return null;
    },
    /**
     * 遍历数组
     * @param {} value
     * @param {} fn
     * @param {} scope
     */
    each: function(value, fn, scope){
		if (Fw.isEmpty(value)) {
		    return;
		}
		if (!Fw.isDefined(scope)) {
		    scope = value;
		}
		if (Fw.isObject(value)) {
			var i = 0;
            for(var prop in value){
                if(value.hasOwnProperty(prop)){
                    if(fn.call(scope || value, prop, value[prop], i++, value) === false){
                        return;
                    };
                }
            }
		}
		else {
			if(!Fw.isIterable(value) || Fw.isPrimitive(value)){
				value = [value];
			}
            for(var i = 0, len = value.length; i < len; i++){
                if(fn.call(scope || value[i], value[i], i, value) === false){
                    return i;
                };
            }
		}
    },
    /**
     * 绑定作用域
     * @param {} fn
     * @param {} scope
     * @return {}
     */
    bind: function(fn, scope) {
    	if(!Fw.isFunction(fn)){
    		return fn;
    	}
        return function() {
            return fn.apply(scope, arguments);
        };
    },
    /**
     * 页面加载完毕后，初始化应用
     * @param {} app
     */
    onReady: function(app){
    	if(app.init){
    		var deps = seajs.parseDependencies(app.init.toString());
	    	if(Fw.isArray(deps)){
	    		if(Fw.BASE_LIB){
	    			deps = Fw.BASE_LIB.concat(deps);
	    		}
	    		Fw.define(deps, Fw.bind(app.init, app));
	    	}
	    	else{
	    		Fw.define(Fw.bind(app.init, app));
	    	}
    	}
    	else{
			Fw.define(app);
    	}
    },
    /**
     * 定义模块
     * 桥接Seajs
     * http://seajs.org
     * @param {} deps
     * @param {} factory
     */
    define: function(factory){
    	if(!Fw.BASE_LIB || arguments.length > 1 || !Fw.isFunction(factory)){
    		define.apply(this, arguments);
    	}
    	else{
    		define.call(this, Fw.BASE_LIB, factory);
    	}
    },
    /**
     * 模版
     * 桥接Juicer
     * http://juicer.name
     */
    template: function(){
    	return juicer.apply(this, arguments);
    },
    /**
     * 显示元素位置
     * @param el
     * @returns {x,y}
     */
    position:function (el) {
        var pos = [el.offsetLeft, el.offsetTop];
        var parent = el.offsetParent;
        if (parent != el) {
            while (parent) {
                pos[0] += parent.offsetLeft;
                pos[1] += parent.offsetTop;
                parent = parent.offsetParent;
            }
        }
        return {
            x : pos[0],
            y : pos[1]
        };
    },
    showPageArea:function(showId,hideIds,showTitle){
    	try{
    		var obj=$(showId); 
    		var show = (showTitle == true) ? false : true;
			if (show) {
				Fw.device.Client.initPageTitle(showId);
			}
    		for(var i=0,j=hideIds.length;i<j;i++){
    			$(hideIds[i]).hide();
    		}
    		obj.show();
    	}catch(e){
    		alert(e);
    	}
    },
    queryByClass:function (oParent, sClass)
    {
		var aEle = oParent.getElementsByTagName('*');
		var aResult = [];
		var re = new RegExp('\\b' + sClass + '\\b', 'i');
		var i = 0;
		for (i = 0; i < aEle.length; i++) {
			if (re.test(aEle[i].className)) {
				aResult.push($(aEle[i]));
			}
		}
		return aResult;
    }
};
//
Fw.namespace('Fw.core', 'Fw.util', 'Fw.device');
