/**
 * @name Fw.device.Android
 * @class 设备交互接口
 * @example : <br>
 *          Fw.device.Client.openWaitPanel();<br>
 *          Fw.device.Client.hideWaitPanel();\n
 */
Fw.device.Android = function() {
};
Fw.override(Fw.device.Android, {
	_WK_DATAS : [],
	/**
	 * 开启等待层
	 */
	openWaitPanel : function() {
		MsgJs.showWaitPanel("加载中...");
	},
	/**
	 * 关闭等待层
	 */
	hideWaitPanel : function() {
		MsgJs.closeWaitPanel();
	},
	/**
	 * 弹出信息
	 * 
	 * @example : <br>
	 * 
	 */
	alertinfo : function(cfg) {
		Fw.applyIf(cfg, {
			title : "系统提示",
			ok_btn : "false",
			ok_func : "确认",
			ok_text : "",
			cancle_text : "确认",
			cancle_func : ""
		});
		window.MsgJs.setAlertInfo(Fw.encode(cfg));
	},
	/**
	 * 返回系统首页
	 */
	gotoHomePage : function() {

	},
	/**
	 * 九宫格页面
	 */
	gotoIndexPage : function() {

	},
	/**
	 * 登录成功后跳转到欢迎页
	 */
	gotoWelcomePage : function() {

	},
	/**
	 * 显示日期键盘
	 * 
	 * @param obj
	 * @example <br>
	 *          &lt;input type="text" id="startDate" data-min="" data-max=""
	 *          data-startId="" data-endId="" readOnly
	 *          onclick="Fw.device.Client.showDatePicker(this)"&gt; <br>
	 */
	showDatePicker : function(elem) {
		Fw.log("----showDatePicker--1--", "Android");
		try {
			var obj = $(elem);
			var val = obj.val();
			if (val == "") {
				val = new Date().format("yyyy-MM-dd");
			}
			var cfg = {
				id : elem.id,
				text : val,
				doubleControl : false,
				isStartControl : false,
				isEndControl : false
			}; 
			// 最小值
			var min = obj.attr("data-min");
			var startId = obj.attr("data-startId");
			var max = obj.attr("data-max");
			var endId = obj.attr("data-endId");
			if (startId) {
				cfg.min = $(startId).val();
				cfg.doubleControl = true;
				cfg.isEndControl = true;
			} else if (min) {
				cfg.min = min;
			}
			if (endId) {
				cfg.max = $(endId).val();
				cfg.doubleControl = true;
				cfg.isStartControl = true;
			} else if (max) {
				cfg.max = max;
			}
			var succ = obj.attr("data-succFunc");
			cfg.callback = succ ? succ : "Fw.device.Client._saveDate(@)";
			var fail = obj.attr("data-failFunc");
			if (fail) {
				cfg.callbackErr = fail;
			}
			this._WK_DATAS["datePick"] = cfg; 
			window.SysClientJs.showdatepick(Fw.encode(cfg));
		} catch (e) {
			alert("showDatePicker error :\n" + e);
		}
		Fw.log("----showDatePicker--end--", "Android");
	},
	_saveDate : function(txt) {
		var cfg = this._WK_DATAS["datePick"];
		$(cfg.id).val(txt);
		_isShowYtKeyBoard = false;
		this._hideKeyboard();
		
	},
	/**
	 * 显示安全键盘
	 * 
	 * @example <br>
	 *          &lt;input type="password" id="password" data-maxlength=""
	 *          data-minlength="" data-kind="" （键盘模式）
	 *          onclick="Fw.device.Client.showPwdPicker(this)"&gt; <br>
	 */
	showPwdPicker : function(ele) {
		//Fw.log("----showPwdPicker--1--", "Android");
		try{
		    alert(1);
			if (this._isShowYtKeyBoard)
				return;
			this._isShowYtKeyBoard = true;
			this._preShowKeyBoard(ele); 
			var cfg = {};
			Fw.applyIf(cfg, {
				text : '',
				id : '',
				callback:'Fw.device.Client._savePassword'});
			var jqObj = $(ele);
			cfg.id = jqObj.attr("id");
			cfg.text = jqObj.val();
			this._WK_DATAS["pwdPick"] = cfg; 
			var cfgStr = Fw.encode(cfg);
	         window.SysClientJs.showAddDigitDialog(cfgStr);
		}catch(e){
			alert("showPwdPicker:"+e);
		}
		this._isShowYtKeyBoard = false;
		//Fw.log("----showPwdPicker--end--", "Android");
	},
	_savePassword : function(ps) {
		//Fw.log("----_savePassword--1--", "Android");
		try{
			var cfg = this._WK_DATAS["pwdPick"];
			var elem = $(cfg.id);
			var pass = ps.split("|");
			var passValue = pass[0]; //RSA加密密文
			var md5Value = pass[1]; //MD5 加密密文
			var passLen = pass[2];  // 实际密码长度
			var isSign = pass[3];  // 判断是否中英文组合
			elem.attr("title",passValue);  //返回密码 ,设置密码,如果是新客户端就取对应id的title值，为加密密码
			elem.lable = md5Value;
			elem.lang = passLen;
			elem.name = isSign;
			if(passLen != null && passLen != ""){
				var len = passLen;
				var showValue = "";
				for(var i=0;i<len;i++){
					showValue +="8";
				}
				elem.val(showValue);
			}else{
				 elem.attr("title","");
				 elem.val("");
			}		
			var c = $("_KeyBoardDiv");
			if (c && c.dom) {
				c.hide();
			}
		}catch(e){
			alert("_savePassword:"+e);
		}
		//Fw.log("----_savePassword--end--", "Android");
	},
	/**
	 * 显示金额键盘
	 * 
	 * @param obj
	 */
	showMoneyPicker : function(ele) {
		//Fw.log("----showMoneyPicker--1--", "Android");
		if (this._isShowYtKeyBoard) {
			return;
		}
		this._isShowYtKeyBoard = true;
		try {
			this._preShowKeyBoard(ele);
			var obj = $(ele);
			var cfg = {};
			cfg.id = obj.attr("id");
			var r = obj.attr("data-right");
			cfg.right = r ? r : 2; // 小数位
			cfg.text = obj.val().replace(/,/g, "");
			cfg.callback = 'Fw.device.Client._saveMoneyData';
			this._WK_DATAS["mnyPick"] = cfg;
			Fw.log(Fw.encode(cfg), "Android");
			window.SysClientJs.showdigitpad(Fw.encode(cfg));
		} catch (e) {
			alert("showMoneyPicker:" + e);
		}
		this._isShowYtKeyBoard = false;
		//Fw.log("----showMoneyPicker--end--", "Android");
	},
	_saveMoneyData : function(s) {
		var cfg = this._WK_DATAS["mnyPick"];
		$(cfg.id).val(Fw.util.Format.money(s,2));
		this._hideKeyboard();
	},
	buileFootdiv : function(ele, rootele) {
		var jianpanH = 210;
		var eleHeight = ele.scrollHeight;
		if (eleHeight < jianpanH) {
			var result = jianpanH - eleHeight;
			return result;
		} else {
			return 0;
		}
	},
	_preShowKeyBoard : function(ele) {
		// return;
		var a = document.body;
		a = a ? a : document.documentElement;
		var h = Fw.position(ele);
		var toolbar = $("toolbar");
		if (toolbar && toolbar.dom) {
			h.y = h.y - 56;
		}
		var c = this.buileFootdiv(ele, a);
		if (c != 0) {
			var d = $("_KeyBoardDiv");
			if (d && d.dom) {
				d.show();
			} else {
				var div = document.createElement("div");
				div.setAttribute("id", "_KeyBoardDiv");
				d = $(div);
			}
			d.dom.style.height = c + "px";
			document.body.scrollTop = h.y - 50;
		} else {
			document.body.scrollTop = ele.scrollHeight + 200;
		}
	},
	_hideKeyboard : function() {
		var c = $("_KeyBoardDiv");
		if (c && c.dom) {
			c.hide();
		}
	},
	/**
	 * 加密数据
	 * 
	 * @param obj
	 */
	encryptTransData : function(obj) {
	},
	/**
	 * 服务端超时
	 */
	sessionTimeOut : function() {
	},
	_generyTitleButton : function(cfg) {
		if (cfg && cfg.length == 3) {
			return {
				exist : cfg[0],
				name : cfg[1],
				func : cfg[2]
			};
		}
		return {
			exist : false
		};
	},
	_getPageTitle : function(pageId) {
		var page = $(pageId);
		var cfg = {
			title : page.attr("title")
		};
		var leftCfg = page.attr("data-btnLeft").split("|");
		cfg.leftButton = this._generyTitleButton(leftCfg);
		var rightCfg = page.attr("data-btnRight").split("|");
		cfg.rightButton = this._generyTitleButton(rightCfg);
		return cfg;
	},
	/**
	 * 初始化页标题栏
	 */
	initPageTitle : function(pageId) {
		var json = this._getPageTitle(pageId);
		window.SysClientJs.updataTitleInfo(Fw.encode(json));
	},
	displayPageArea : function(curPageId, hidenPages) {
		$(curPageId).show();
		Fw.each(hidenPages, function(pageId, index) {
			$(pageId).hide();
		});
	}
});

//
Fw.device.Client = new Fw.device.Android();
