/**
 * @name Fw.device.iPhone
 * @class 设备交互接口
 * @example : <br>
 *          Fw.device.Client.openWaitPanel();<br>
 *          Fw.device.Client.hideWaitPanel();\n
 */
Fw.device.iPhone = function(){
	var W = window;
	// 事件队列
	W._mevents = new Array();
	// push 增加入队列
	// shift 先进先出
	// 设置自定义事件
	W.setWebitEvent = function(evtName, evtCode) {
		if (evtName == "") {
			return;
		}
		_mevents.push(Fw.encode({
			code : evtCode,
			name : evtName
		}));
	};
	// 获取EventCode
	W.getWebkitEventCode = function() {
		return _mevents.length > 0 ? _mevents.shift() : "0";
	};
	// 获取自定义事件
	W.getWebkitEvent = function() {
		return "";
	};

	W._WK_DATAS = [];
	W._WK_DATAS["wait"] = "{'msg':'','callback':'','touchable':'false'}";
	W.showWaitPanel = function() {
		return Fw.encode(_WK_DATAS["wait"]);
	};
	W.closeWaitPanel = function() {
		_WK_DATAS["wait"] = "{}";
	};

	W._WK_DATAS["alert"] = {'title':'温馨提示','msg':'测试信息'};
	// 获取提示信息
	W.getAlertInfo = function() {
		return Fw.encode(_WK_DATAS["alert"]);
	};

	/*-------------------------------------------------------------------
	 * 显示日期框
	 * */
	W._WK_DATAS["datePick"] = {
		text : '2011-01-15',
		formate : 'yyyy-MM-dd',
		min : '2011-01-01',
		max : '2011-12-31',
		callback : '_saveDate(@)'
	};
	W._getDatePicker = function() {
		return Fw.encode(_WK_DATAS["datePick"]);
	};
	W._saveDate = function(txt) {
		var cfg = _WK_DATAS["datePick"];
		$(cfg.id).val(txt);
		_isShowYtKeyBoard = false;
		var d = $("_KeyBoardDiv");
		if (d != undefined) {
			d.hide();
		}
		
	};
	/*-------------------------------------------------------------------*/
	// 金额键盘
	W._WK_DATAS["mnyPick"] = { 
		text : '', 
		left : '10',
		right : '2',
		min : '0',
		max : '',
		callback : '_saveMoneyData'
	};
	W._getMoneyPicker = function() {
		_isShowYtKeyBoard=false;
		return Fw.encode(_WK_DATAS["mnyPick"]);
	};
	// 金额键盘回调方法
	W._saveMoneyData = function(s) {
		var cfg = _WK_DATAS["mnyPick"];
		var ele = $(cfg.id);
		ele.val(s);
		var c = $("_KeyBoardDiv");
		if (c != undefined) {
			c.hide();
		}
	};

	W._isShowYtKeyBoard = false;
	W.buileFootdiv = function(ele, rootele) {
		var jianpanH = 210;
		var eleHeight = ele.scrollHeight;
		if (eleHeight < jianpanH) {
			var result = jianpanH - eleHeight;
			return result;
		} else {
			return 0;
		}
	}; 
	/*-------------------------------------------------------------------*/
	// 密码键盘
	W._WK_DATAS["pwdPick"] =  {id:'',text:'',randomNumber:'111111',max:'6',min:"6",errorMsg:"",nullMsg:"",callback:'_savePassword',state:'state'};
	W._getPwdPicker = function() {
		_isShowYtKeyBoard=false;
		return Fw.encode(_WK_DATAS["pwdPick"]);
	};
	// 密码回调方法
	W._savePassword = function(ps) {
		try{
			var cfg = _WK_DATAS["pwdPick"];
			var elem = $(cfg.id);
			var pass = ps.split("|");
			var passValue = pass[0]; //RSA加密密文
			var md5Value = pass[1]; //MD5 加密密文
			var passLen = pass[2];  // 实际密码长度
			var isSign = pass[3];  // 判断是否中英文组合
			elem.attr("title",passValue);  //返回密码 ,设置密码,如果是新客户端就取对应id的title值，为加密密码
			elem.lable = md5Value;
			elem.lang = passLen;
			elem.name = isSign;
			if(passLen != null && passLen != ""){
				var len = passLen;
				var showValue = "";
				for(var i=0;i<len;i++){
					showValue +="8";
				}
				elem.val(showValue);
			}else{
				 elem.attr("title","");
				 elem.val("");
			}		
			var c = $("_KeyBoardDiv");
			if (c && c.dom) {
				c.hide();
			}
		}catch(e){
			alert("_savePassword:"+e);
		}
	};
};
Fw.override(Fw.device.iPhone, {
	/**
	 * 开启等待层
	 */
	openWaitPanel : function(cfg) {
		_WK_DATAS["wait"] = cfg;
		setWebitEvent('showWaitPanel()', '04');
	},
	/**
	 * 关闭等待层
	 */
	hideWaitPanel : function() {
		setWebitEvent('closeWaitPanel()', '04');
	},
	/**
	 * 弹出信息
	 * 
	 * @example : <br>
	 * 
	 */
	alertinfo : function(cfg) {
		_WK_DATAS["alert"] = cfg;
		setWebitEvent("getAlertInfo()", "05");
	},
	/**
	 * 返回系统首页
	 */
	gotoHomePage : function() {

	},
	/**
	 * 九宫格页面
	 */
	gotoIndexPage : function() {

	},
	/**
	 * 登录成功后跳转到欢迎页
	 */
	gotoWelcomePage : function() {

	},
	/**
	 * 显示日期键盘
	 * 
	 * @param obj
	 * @example <br>
	 *          <input type="text" id="startDate" data-min="" data-max=""
	 *          data-startId="" data-endId="" readOnly
	 *          onclick="Fw.device.Client.showDatePicker(this)"><br>
	 */
	showDatePicker : function(elem) {
		try {
			var obj = $(elem);
			var cfg = {
				id : elem.id,
				text : obj.val()
			};
			var fmt = obj.attr("data-format");
			if (fmt) {
				cfg.formate = fmt;
			}
			// 最小值
			var min = obj.attr("data-min");
			var startId = obj.attr("data-startId");
			var max = obj.attr("data-max");
			var endId = obj.attr("data-endId");
			if (startId) {
				cfg.min = $(startId).val();
			} else if (min) {
				cfg.min = min;
			}
			if (endId) {
				cfg.max = $(endId).val();
			} else if (max) {
				cfg.max = max;
			}
			var succ = obj.attr("data-succFunc");
			cfg.callback = "_saveDate(@);" + (succ ? succ : "");
			var fail = obj.attr("data-failFunc");
			if (fail) {
				cfg.callbackErr = fail;
			}
			_WK_DATAS["datePick"] = cfg;
			setWebitEvent('_getDatePicker()', '09');
		} catch (e) {
			alert("showDatePicker error :\n" + e);
		}
	},
	/**
	 * 显示安全键盘
	 */
	showPwdPicker : function(ele) {
		try{
			if (_isShowYtKeyBoard)
				return;
			_isShowYtKeyBoard = true;
			this._preShowKeyBoard(ele);
			var cfg = _WK_DATAS["pwdPick"];
			var jqObj = $(ele);
			cfg.id = jqObj.attr("id");
			var maxL = jqObj.attr("maxLength");
			if (maxL) {
				maxL *= 1;
				maxL = Math.max(6, maxL);
			} else {
				maxL = 6;
			}
			cfg.max = maxL;
			if(maxL == 20){
				cfg.errorMsg="密码支持6-20位的数字英文字母，大小写敏感，不允许设置纯数字、相同字母等过于简单的密码 ！";
			}else if (maxL == 8){
				cfg.errorMsg="密码支持6-8位的数字或英文字母！";
			}else {
				cfg.errorMsg="密码不能小于6位，请核对后重新输入！";
			}
			var flag=jqObj.attr("pwd-type");
			_WK_DATAS["pwdPick"] = cfg;
			setWebitEvent('_getPwdPicker()', (flag=="2"?'GUA2':'GUA1'));
		}catch(e){
			alert("showPwdPicker:"+e);
		}
	},
	/**
	 * 显示金额键盘
	 * 
	 * @param obj
	 */
	showMoneyPicker : function(ele) {
		try{
			if (_isShowYtKeyBoard)
				return;
			_isShowYtKeyBoard = true;
			this._preShowKeyBoard(ele);
			var cfg = _WK_DATAS["mnyPick"];
			cfg.id = $(ele).attr("id"); 
			cfg.text = $(ele).val();
			cfg.callback = '_saveMoneyData';
			_WK_DATAS["mnyPick"] = cfg;
			setWebitEvent('_getMoneyPicker()', '12');
		}catch(e){
			alert("showMoneyPicker:"+e);
		}
	},
	_preShowKeyBoard:function(ele){
		// return;
		var a = document.body;
		a = a ? a : document.documentElement;
		var h = Fw.position(ele);
		var toolbar = $("toolbar");
		if (toolbar) {
			h.y=h.y - 56;
		}
		var c = buileFootdiv(ele, a);
		if (c != 0) {
			var d = $("_KeyBoardDiv");
			if (d && d.dom) {
				d.show();
			} else {
				var div = document.createElement("div");
				div.setAttribute("id", "_KeyBoardDiv");
				d = $(div);
			}
			d.dom.style.height = c + "px";
			document.body.scrollTop = h.y - 50; 
		} else {
			document.body.scrollTop = ele.scrollHeight + 200;
		}		 
	},
	/**
	 * 服务端超时
	 */
	sessionTimeOut : function() {
	},
	_generyTitleButton : function (cfg){
		if (cfg && cfg.length == 3) {
			return {
				exist : cfg[0],
				name : cfg[1],
				func : cfg[2]
			};
		} 
		return {
			exist : false
		};
	},
	_getPageTitle:function (pageId) {
		var page = $(pageId);
		var cfg = {
			title : page.attr("title")
		};
		var leftCfg = page.attr("data-btnLeft").split("|");
		cfg.leftButton = this._generyTitleButton(leftCfg);
		var rightCfg = page.attr("data-btnRight").split("|");
		cfg.rightButton = this._generyTitleButton(rightCfg);
		return Fw.encode(cfg);
	},
	/**
	 * 初始化页标题栏
	 */
	initPageTitle:function(pageId){
		setWebitEvent("Fw.device.Client._getPageTitle('"+pageId+"')", "02");
	},
	displayPageArea : function(curPageId,hidenPages) {
		$(curPageId).show();
		Fw.each(hidenPages, function(pageId, index) {
			$(pageId).hide();
		});
	}
});

//
Fw.device.Client = new Fw.device.iPhone();

//

