/**
 * 
 * @name Fw.util.Ajax
 * @class 异步请求工具类，不支持跨域访问
 * @constructor
 * @example
 * @description 公共交易请求 TransAjax
 * @return
 */
Fw.util.Ajax = function(config){
	Fw.apply(this, config);
	//call parent
	Fw.util.Ajax.superclass.constructor.call(this);
	//
	if(this.autoLoad){
		this.load();
	}
	return this;
};
Fw.extend(Fw.util.Ajax, Fw.util.Observable, {
	timeout: 30000,
	showError: false,//是否显示错误信息
	autoLoad: true,
	autoDecode: true,
	params: {},
	/**
	 * 清除超时监听
	 * @param {} xhr
	 */
	clearTimeout: function(xhr) {
		this.cleanup(xhr);
		if (this._timeoutHandle) {
			clearTimeout(this._timeoutHandle);
		}
	},
	/**
	 * 清除xhr
	 * @param {} xhr
	 */
    cleanup: function(xhr) {
		xhr = null;
		delete xhr;
		this.isLoading = false;
    },
	/**
	 * 监听超时
	 * @param {} xhr
	 */
	timeoutListenser: function(xhr){
		if (this.timeout > 0) {
			var me = this;
			this._timeoutHandle = setTimeout(function() {
				if (xhr) {
					xhr.cancel = true;
					xhr.abort();
					me.cleanup(xhr);
					if(Fw.device.Client && Fw.device.Client.alertinfo){
						Fw.device.Client.hideWaitPanel();
						Fw.device.Client.alertinfo("系统繁忙，资金类交易请及时核对账户信息！");
					}
				}
			}, this.timeout);
		}
	},
	/**
	 * 加载数据/页面
	 * @param {} options
	 */
	load: function(options){
		var me = this;
		Fw.apply(me.params, options);
		me.lastOptions = options;
		//
		if(me.fireEvent('beforeload', me) !== false){
			me.isLoading = true;
			var xhr = $.ajax(me.url, me.params, function(responseText){
				if(me.autoDecode){
					try {
						//自动解码
						var data = Fw.decode(responseText);
						if (data && data.STATUS) {
							if (data.STATUS === '005') {
								Fw.device.Client.sessionTimeOut();// session超时;
							} 
							else if (String(data.STATUS) !== '1' && me.showError) {
								Fw.device.Client.alertinfo(data.MSG);
							}
						}
					} 
					catch (e) {
						Fw.device.Client.alertinfo("请求数据错误:" + e);
					}
					me.fireEvent('load', me, data, responseText);
				}
				else{
					me.fireEvent('load', me, responseText);
				}
				me.clearTimeout(xhr);
			});
			me.timeoutListenser(xhr);
		}
	},
	/**
	 * 重载
	 */
	reload: function(){
		this.load(this.lastOptions);
	}
});
//
Fw.Ajax = Fw.util.Ajax;