/**
 * 
 * @name Fw.util.Format
 * @example
 * @description 公共交易请求 TransAjax
 * @return
 */
Fw.util.Format = {
	/**
	 * 格式化账户号
	 * @param {} acc
	 * @param {} mask
	 * @return {}
	 */
	fmtAcctNo: function(acc, mask){
		acc = String(acc).trim();
		var str = '';
		if(!Fw.isEmpty(acc)){
			while (acc.length > 4) {
				if(mask && (acc.length === 8)){
					str = str + '****' + ' ';
				}
				else{
					str = str + acc.substring(0, 4)+ ' ';
				}
			    acc = acc.substring(4, acc.length);
			}
			str += acc;
		}
		return str;
	},
	/**
	 * 格式化账户类型
	 * @param {} type
	 */
	fmtAcctType: function(type, a){
		var text = type;
		switch(String(type)){
			case '0':
				text = '对公账号';
				break;
			case '1':
				text = '借记卡';
				break;
			case '2':
				text = '活期一本通';
				break;
			case '3':
				text = '定期一本通';
				break;
			case '8':
				text = '对私账户';
				break;
			case 'A':
				text = 'ARAP影子账户';
				break;
			case 'C':
				text = '信用卡';
				break;
			case 'T':
				text = 'DM技术账户';
				break;
		}
		return text;
	},
	/**
	 * 日期格式化
	 * @param {} v
	 * @param {} format
	 */
	fmtDate: function(v, format){
		if(!v) return null;
		if (!Fw.isDate(v)) {
			if(v.length == 8){
				return v.substring(0, 4) + '年' + v.substring(4, 6) + '月' + v.substring(6, 8) + '日';
			}
			else if(v.length == 14){
				return v.substring(0, 4) +
				       '年' + v.substring(4, 6) + 
				       '月' + v.substring(6, 8) + 		       
				       '日' + v.substring(8, 10) + 
				       '时' + v.substring(10, 12) + 
				       '分' + v.substring(12, 14) + '秒';
			}
			else if(v.length == 6){
				return v.substring(0, 2) +
				       '时' + v.substring(2, 4) + 
				       '分' + v.substring(4, 6) + '秒';
			}
			else{
				v = String(v).split('.')[0];
				v = v.replace(/-/g, '/').replace('年', '/').replace('月', '/').replace('日', '').replace('时', ':').replace('分', ':').replace('秒', '');
				v = new Date(Fw.isNumber(v*1) ? v*1 : Date.parse(v));
			}
		}
		return v.format(format || 'yyyy年MM月dd日');
	},
	/**
	 * 格式化金额
	 * @param {} v
	 * @param {} c
	 * @param {} d
	 * @param {} t
	 * @return {}
	 */
	fmtMoney: function(v, c, d, t){
		v *= 1;
		var p =v < 0 ? '-' : '';
		v = v.toFixed(c);
		c = Math.abs(c) + 1 ? c : 2;
		d = d || '.';
		t = t || ',';
		var m = (/(\d+)(?:(\.\d+)|)/.exec(v + ''));
		x = m[1].length > 3 ? m[1].length % 3 : 0;
		return p + (x ? m[1].substr(0, x) + t : '')
				+ m[1].substr(x).replace(/(\d{3})(?=\d)/g, '$1' + t)
				+ (c ? d + (+m[2] || 0).toFixed(c).substr(2) : '');
	}
};

/**
 * 注册到juicer
 */
Fw.each(Fw.util.Format, function(prop, fun){
	juicer.register(prop, fun);
});

/**
 * 时间对象格式化
 * @param {} format
 * @return {}
 */
Date.prototype.format = function(format) { 
	var o = {
		'y+' : this.getFullYear(), // year
		'M+' : this.getMonth() + 1, // month
		'd+' : this.getDate(), // day
		'h+' : this.getHours(), // hour
		'm+' : this.getMinutes(), // minute
		's+' : this.getSeconds(), // second
		'q+' : Math.floor((this.getMonth() + 3) / 3), // quarter
		'S' : this.getMilliseconds() // millisecond
	}
	if (/(y+)/.test(format)) {
		format = format.replace(RegExp.$1, (this.getFullYear() + '').substr(4
						- RegExp.$1.length));
	}
	for (var k in o) {
		if (new RegExp('(' + k + ')').test(format)) {
			format = format.replace(RegExp.$1, RegExp.$1.length == 1
							? o[k]
							: ('00' + o[k]).substr(('' + o[k]).length));
		}
	}
	return format;
};