/**
 * @name Fw.ListView_web
 * @class 列表组件
 * @constructor
 * @example
 * @return
 */
Fw.ListView = Fw.extend(Fw.Component, {
	//每页条数
	pageSize: 10,
	//当前页
	currentPage: 1,
	nextKeyField : 'NEXT_KEY',
	morePrev : false,
	moreNext : false,
	//最大缓存页数
	//maxPages: 6,
	pullText: '下拉开始刷新',
	releaseRefreshText: '松开立即刷新',
	loadMoreText: '加载更多...',
	emptyText: '没有数据',
	emptyTpl: '${emptyText}',
	itemCls: 'item',
	pressedCls: 'pressed',
	/**
	 * 初始化组件
	 */
	initComponent: function(){
		Fw.ListView.superclass.initComponent.call(this);
		//新建ajax工具类
		this.ajax = new Fw.Ajax(Fw.apply(this.ajax, {
			autoLoad: false
		}));
		//初始化滑动翻页
		if(this.page === false){
			this.pageSize = 0;
		}
		else{
			this.initScrollable();
		}
	},
	/**
	 * 初始化事件
	 */
	initEvents: function(){
		this.ajax.on('load', this.onLoadData, this); 
		this.body.on('scoll', Fw.bind(this.onScoll, this));
		if(this.page !== false){
			//加载最新
			this.on('refresh', this.onRefresh);
			//加载更多
			this.on('loadmore', this.onLoadMore);
		}
	},
	/**
	 * 初始化HTML模版
	 */
	initTpl: function(){
		var tpl = [], id = Fw.id();
		if(this.page !== false){
			tpl.push('<div id="${id}-pullrefresh" class="pullrefresh hidden">'+ 
								'<div class="pullrefresh-arrow"></div>'+ 
								'<div class="pullrefresh-text"></div>'+ 
							'</div>');
		}
		//
		tpl.push('<div id="${id}-empty" class="empty hidden">');
		tpl.push(this.emptyTpl);
		tpl.push('</div>');
		tpl.push('<div id="${id}" class="body"></div>');
		//
		if(this.page !== false){
			tpl.push('<div id="${id}-loadmore" class="loadmore hidden">${loadMoreText}</div>');
		}
		this.el.html(Fw.template(tpl.join(''), {
			id: id,
			emptyText: this.emptyText,
			loadMoreText: this.loadMoreText
		}));
		this.emptyEl = $(id + '-empty');
		this.body = $(id);
		//
		this.tpl = [];
		if(Fw.isArray(this.itemTpl)){
			this.itemTpl = this.itemTpl.join('');
		}
		this.tpl.push('<ul>');
		this.tpl.push('{@each data as item,index}');
		this.tpl.push('<li class="${itemCls} ${disclosureCls}" _index="${index}" _page="${page}">');
		this.tpl.push(this.itemTpl);
		this.tpl.push('</li>');
		this.tpl.push('{@/each}');
		this.tpl.push('</ul>');
		this.tpl = Fw.template(this.tpl.join(''));
	},
	/**
	 * 初始化滑动翻页
	 */
	initScrollable: function() {
		var bodyId = this.body.attr('id');
		this.pullRefreshEl = $(bodyId + '-pullrefresh');
		this.pullRefreshArrowEl = $(this.pullRefreshEl.dom.childNodes[0]);
		this.pullRefreshTextEl = $(this.pullRefreshEl.dom.childNodes[1]);
		this.loadMoreEl = $(bodyId + '-loadmore');
		var me = this;
		///
		Fw.apply(me, {
			//滚动距离
			getScrollTop: function(){
				var bodyScrollTop = 0, documentScrollTop = 0;
				if(document.body){
					bodyScrollTop = document.body.scrollTop;
				}
				if(document.documentElement){
					documentScrollTop = document.documentElement.scrollTop;
				}
				return (bodyScrollTop - documentScrollTop > 0) ? bodyScrollTop : documentScrollTop;
			},
			//文档高度
			getScrollHeight: function(){
				var bodyScrollHeight = 0, documentScrollHeight = 0;
				if(document.body){
					bodyScrollHeight = document.body.scrollHeight;
				}
				if(document.documentElement){
					documentScrollHeight = document.documentElement.scrollHeight;
				}
				return (bodyScrollHeight - documentScrollHeight > 0) ? bodyScrollHeight : documentScrollHeight;
			},
			//浏览器高度
			getWindowHeight: function(){
				if(document.compatMode == "CSS1Compat"){
					return document.documentElement.clientHeight;
				}
				else{
					return document.body.clientHeight;
				}
			}
		});
		//定义触摸事件
		var startPosition, endPosition; 
		document.addEventListener("scroll", function(e){
			if(me.enable()==false)
				return;
			delete me.pullEventName;
			if(me.ajax.isLoading){
				return;
			}
			// 判断是否有下页，有则继续，无则返回；
			if(!me.moreNext){
				//return;
			}			
			endPosition = startPosition - e.touches[0].pageY;
			// 头部--向前翻页
			if(me.pullRefresh !== false && me.getScrollTop() < 0){
				me.pullRefreshArrowEl.removeClass('pullrefresh-release');
				if(Math.abs(endPosition) > 100){
					me.pullRefreshTextEl.html(me.releaseRefreshText);
					me.pullRefreshArrowEl.addClass('pullrefresh-release');
					me.fireEvent("refresh", me);///向前翻页
				}
				else if(Math.abs(endPosition) > 40){
					me.pullRefreshEl.show();
					me.pullRefreshTextEl.html(me.pullText);
				}
				else{
					me.pullRefreshEl.hide();
				}
				me.loadMoreEl.hide();
			}
			//尾部--向后翻页
			else if(me.getScrollTop() + me.getWindowHeight() > me.getScrollHeight() - 150){
				me.loadMoreEl.show();
				me.fireEvent("loadmore", me);///向后翻页
			} 
			me.pullRefreshEl.hide();
		});
		//
	},
	/**
	 * 加载最新
	 */
	onRefresh: function(){
		this.loadData(1);
	},
	/**
	 * 加载更多
	 */
	onLoadMore: function(){
		this.loadData(this.currentPage + 1);
	},
	/**
	 * 载入数据
	 * @param {} page
	 */
	loadData: function(page){
		page = page || 1;
		this.currentPage = page;
		this.emptyEl.hide();
		var params = {};
		params[this.pageStartField] = (page - 1) * this.pageSize;
		params[this.pageLimitField] = this.pageSize;
		this.ajax.load(params);
	},
	/**
	 * 载入数据后触发
	 * @param {} ajax
	 * @param {} data
	 */
	onLoadData: function(ajax, data){
		//
		data = data ? (this.dataField ? data[this.dataField] : data) : null;
		this.moreNext = false;
		if(this.data){
			// 判断是否有下页，有下页时nextMore=true;
			var nextKey = data[this.nextKeyField];
			if(nextKey){
				this.moreNext = true;
				this.nextKey = nextKey;
			}
			// 合并数据
			this.data = this.data.concat(data);
		}
		else{
			this.data = data;
		}
		//
		if(!Fw.isArray(this.data) || this.data.length === 0){
			this.emptyEl.show();
		}
		else{
			//将HTML渲染到页面
			this.body[this.currentPage === 1 ? 'html' : 'append'](this.tpl.render({
				itemCls: this.itemCls,
				disclosureCls: this.disclosure ? 'disclosure' : '',
				page: this.currentPage,
				data: data
			}));
		}
		//
		if(this.loadMoreEl){
			this.loadMoreEl.hide();
		}
	},
	/**
	 * Item Touch Start时触发
	 * @param {} e
	 */
	onScroll: function(e){ 
	}, 
	onClick: function(e){
		if(this.tapItem){
			var index = this.tapItem.attr('_index') * 1 + (this.tapItem.attr('_page') - 1) * this.pageSize;
			this.tapItem.removeClass(this.pressedCls);
			this.fireEvent('itemtap', this.data[index], index, this.tapItem, e, this);
			delete this.tapItem;
		}
	}
});