/**
 * @name Fw.Toolbar
 * @class 工具条组件
 * @constructor
 * @example
 * @return
 */
Fw.Toolbar = Fw.extend(Fw.Component, {
	wrapCls: 'tabs',
	itemCls: 'tab',
	itemActiveCls: 'selected',
	tpl: [
		'<div class="${wrapCls}">',
			'{@each data as item,index}',//
				'<div class="${itemCls} ${item.itemActiveCls}" _index="${index}"><span class="${item.iconCls}"></span><label>${item.text}</label></div>',
			'{@/each}',
		'</div>'
	],
	/**
	 * 初始化组件
	 */
	initComponent: function(){
		Fw.Toolbar.superclass.initComponent.call(this);
		var index = -1;
		Fw.each(this.items, function(item, idx){
			item.itemActiveCls = '';
			if(index<0 && item.active){
				item.itemActiveCls = this.itemActiveCls;
				index = idx;
			}else{
				delete item.active;
			}
		}, this);
		//将HTML渲染到页面
		this.el.html(this.tpl.render({
			wrapCls: this.wrapCls+" col_"+this.items.length,
			itemCls: this.itemCls,
			data: this.items
		}));
		if(index>=0) this.activeItem = $(this.el.dom.children[0].children[index]);
	},
	/**
	 * 初始化事件
	 */
	initEvents: function(){
		$(this.el.dom.children[0]).on('touchend', Fw.bind(this.onItemTouch, this));
	},
	/**
	 * 初始化HTML模版
	 */
	initTpl: function(){
		this.tpl = Fw.template(this.tpl.join(''));
	},
	/**
	 * 单击按钮时触发
	 * @param {} e
	 */
	onItemTouch: function(e){
		var target, el;
		if(!e || !(target = e.target)){
			return false;
		}
		// 检查当前节点是否为TAB
		if(!(el = $(target)).hasClass(this.itemCls)){
			//检查父节点是否为TAB，并重新定义节点
			if(!(el=el.parent()).hasClass(this.itemCls) || el.hasClass(this.itemActiveCls))
				return false;
		} else if(el.hasClass(this.itemActiveCls)){
			return false;
		}
		Fw.log("--onItemTouch--begin-----", "Toolbar");
		var index = el.attr('_index')*1;
		el.addClass(this.itemActiveCls);
		if(this.activeItem) this.activeItem.removeClass(this.itemActiveCls);
		this.activeItem = el;
		this.fireEvent('itemtap', this.items[index], index, el, e, this);
	}
});